starcluster.balancers.sge

Package starcluster :: Package balancers :: Package sge |
[hide private]
[frames] | no frames]

# Package sge

source code

Submodules | [hide private]
starcluster.balancers.sge.visualizer: StarCluster SunGrinEngine stats visualizer module

Classes | [hide private]
| SGEStats SunGridEngine stats parser
| SGELoadBalancer This class is able to query each SGE host and return load & queue statistics

Variables | [hide private]
| SGE_STATS_DIR = ``'``/home/jtriley/.starcluster/sge``'``
| DEFAULT_STATS_DIR = ``'``/home/jtriley/.starcluster/sge/%s``'``
| DEFAULT_STATS_FILE = ``'``/home/jtriley/.starcluster/sge/%s/sge-st``...``
| __package__ = ``'``starcluster.balancers.sge``'``

Variables Details | [hide private]

  ### DEFAULT_STATS_FILE Value:
      '/home/jtriley/.starcluster/sge/%s/sge-stats.csv'